==> mgb-0.6.7.1.tar.bz2: install/upgrade/064.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ============ //
	// 064.php - 1.0 //
	// ============ //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

$sql = array();

$sql[1] = "CREATE TABLE ".$db['prefix']."captcha_math (
	`math` VARCHAR( 20 ) NOT NULL ,
	  `sum` INT NOT NULL ,
	  PRIMARY KEY ( `math` )
	  ) TYPE = MYISAM;";
$sqldescription[1] = "- Creating table for new captcha...";

$sql[2] = "INSERT INTO ".$db['prefix']."captcha_math (
		`math` ,
		`sum`
	) VALUES (
		'1+2+3' ,
		'6'
		);";
$sqldescription[2] = "- Inserting default values...";

$sql[3] = "ALTER TABLE `".$db['prefix']."settings` ADD `captcha_method` TINYINT( 1 ) DEFAULT '0' NOT NULL AFTER `captcha` ;";
$sqldescription[3] = "- Inserting field for new captcha method...";

$sql[4] = "ALTER TABLE `".$db['prefix']."settings` ADD `akismet_plugin` TINYINT( 1 ) DEFAULT '0' NOT NULL AFTER `captcha_method` ;";
$sqldescription[4] = "- Inserting field for akismet support...";

$sql[5] = "ALTER TABLE `".$db['prefix']."settings` ADD `akismet_api` VARCHAR( 50 ) NOT NULL AFTER `akismet_plugin` ;";
$sqldescription[5] = "- Inserting field for akismet support (API)...";

$sql[6] = "ALTER TABLE `".$db['prefix']."settings` ADD `akismet_mark_as_spam` TINYINT( 1 ) DEFAULT '1' NOT NULL AFTER `akismet_api` ;";
$sqldescription[6] = "- Inserting field for akismet spam-marking (settings)...";

$sql[7] = "ALTER TABLE `".$db['prefix']."entries` ADD `isspam` TINYINT( 1 ) NOT NULL AFTER `checked` ;";
$sqldescription[7] = "- Inserting field for akismet spam-marking (entries)...";

$sql[8] = "ALTER TABLE `".$db['prefix']."user` ADD `r_spam` TINYINT( 1 ) NOT NULL AFTER `r_edit` ;";
$sqldescription[8] = "- Inserting field for new user right 'manage spam'...";

$sql[9] = "ALTER TABLE `".$db['prefix']."settings` ADD `time_lock` INT( 1 ) NOT NULL AFTER `akismet_mark_as_spam` , ADD `time_lock_value` INT( 3 ) DEFAULT '30' NOT NULL AFTER `time_lock` , ADD `time_lock_maxtime` INT DEFAULT '300' NOT NULL AFTER `time_lock_value` ";
$sqldescription[9] = "- Inserting fields for time lock (settings)...";

// update version number every time
if($settings['version'] == "0.6.4")
	{
	$sql[10] = "UPDATE `".$db['prefix']."settings` SET `version` = '0.6.6'";
	$sqldescription[10] = "- Updating version number...";
	}
else
	{
	$sql[10] = "UPDATE `".$db['prefix']."settings` SET `version` = '".MGB_VERSION."'";
	$sqldescription[10] = "- Updating version number...";
	}

$to = 10;

$config_file = "<?"."php\n\n";
$config_file .= "\t"."// THIS FILE WAS AUTOMATICALLY GENERATED BY MGB\n";
$config_file .= "\t"."// DO NOT MODIFY IT!\n\n";
$config_file .= "\t"."// Database settings\n";
$config_file .= "\t"."\$db = array();\n\n";
$config_file .= "\t"."\$db['hostname'] = '".$db['hostname']."';\n";
$config_file .= "\t"."\$db['dbname'] = '".$db['dbname']."';\n";
$config_file .= "\t"."\$db['username'] = '".$db['username']."';\n";
$config_file .= "\t"."\$db['password'] = '".$db['password']."';\n";
$config_file .= "\t"."\$db['prefix'] = '".$db['prefix']."';\n\n";
$config_file .= "\t"."\$mgb_installation_complete = TRUE;\n";
$config_file .= "?>";

if(write_config("../includes/config.inc.php", $config_file) === TRUE)
	{
	echo "\t\t<span style=\"font-family: verdana, arial, helvetica, sans-serif; font-size: 12px; font-weight: bold;\">- rewriting config.inc.php...</span>\n
	\t\t<span style=\"font-family: verdana, arial, helvetica, sans-serif; font-size: 12px; font-weight: bold; color: green;\">&nbsp;OK!<br /></span>\n";
	$success++;
	$count++;
	}
else
	{
	echo "\t\t<span style=\"font-family: verdana, arial, helvetica, sans-serif; font-size: 12px; font-weight: bold;\">- rewriting config.inc.php...</span>\n
	\t\t<span style=\"font-family: verdana, arial, helvetica, sans-serif; font-size: 12px; font-weight: bold; color: red;\">ERROR!<br /></span>\n";
	$count++;
	}
?>

==> mgb-0.6.8.tar.bz2: install/upgrade/064.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ============ //
	// 064.php - 1.0 //
	// ============ //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

$sql = array();

$sql[1] = "CREATE TABLE ".$db['prefix']."captcha_math (
	`math` VARCHAR( 20 ) NOT NULL ,
	  `sum` INT NOT NULL ,
	  PRIMARY KEY ( `math` )
	  ) TYPE = MYISAM;";
$sqldescription[1] = "- Creating table for new captcha...";

$sql[2] = "INSERT INTO ".$db['prefix']."captcha_math (
		`math` ,
		`sum`
	) VALUES (
		'1+2+3' ,
		'6'
		);";
$sqldescription[2] = "- Inserting default values...";

$sql[3] = "ALTER TABLE `".$db['prefix']."settings` ADD `captcha_method` TINYINT( 1 ) DEFAULT '0' NOT NULL AFTER `captcha` ;";
$sqldescription[3] = "- Inserting field for new captcha method...";

$sql[4] = "ALTER TABLE `".$db['prefix']."settings` ADD `akismet_plugin` TINYINT( 1 ) DEFAULT '0' NOT NULL AFTER `captcha_method` ;";
$sqldescription[4] = "- Inserting field for akismet support...";

$sql[5] = "ALTER TABLE `".$db['prefix']."settings` ADD `akismet_api` VARCHAR( 50 ) NOT NULL AFTER `akismet_plugin` ;";
$sqldescription[5] = "- Inserting field for akismet support (API)...";

$sql[6] = "ALTER TABLE `".$db['prefix']."settings` ADD `akismet_mark_as_spam` TINYINT( 1 ) DEFAULT '1' NOT NULL AFTER `akismet_api` ;";
$sqldescription[6] = "- Inserting field for akismet spam-marking (settings)...";

$sql[7] = "ALTER TABLE `".$db['prefix']."entries` ADD `isspam` TINYINT( 1 ) NOT NULL AFTER `checked` ;";
$sqldescription[7] = "- Inserting field for akismet spam-marking (entries)...";

$sql[8] = "ALTER TABLE `".$db['prefix']."user` ADD `r_spam` TINYINT( 1 ) NOT NULL AFTER `r_edit` ;";
$sqldescription[8] = "- Inserting field for new user right 'manage spam'...";

$sql[9] = "ALTER TABLE `".$db['prefix']."settings` ADD `time_lock` INT( 1 ) NOT NULL AFTER `akismet_mark_as_spam` , ADD `time_lock_value` INT( 3 ) DEFAULT '30' NOT NULL AFTER `time_lock` , ADD `time_lock_maxtime` INT DEFAULT '300' NOT NULL AFTER `time_lock_value` ";
$sqldescription[9] = "- Inserting fields for time lock (settings)...";

$sql[10] = "CREATE TABLE ".$db['prefix']."smilies (
	  `ID` INT NOT NULL AUTO_INCREMENT PRIMARY KEY ,
	  `path` VARCHAR( 255 ) NOT NULL ,
	  `replacement` VARCHAR( 255 ) NOT NULL ,
	  `height` TINYINT( 4 ) NOT NULL ,
	  `width` TINYINT( 4 ) NOT NULL
	  ) TYPE = MYISAM;";
$sqldescription[10] = "- Adding table for smilies...";

$sql[11] = "INSERT INTO ".$db['prefix']."smilies ( 
	  `ID` ,
	  `path` ,
	  `replacement` ,
	  `height` ,
	  `width`
	  ) VALUES 	( NULL , 'smiley_angry.gif', ':angry:', '15', '15' ),
				( NULL , 'smiley_biggrin.gif', ':biggrin:', '15', '15' ),
				( NULL , 'smiley_confused.gif', ':confused:', '15', '15' ),
				( NULL , 'smiley_cool.gif', ':cool:', '15', '15' ),
				( NULL , 'smiley_eek.gif', ':eek:', '15', '15' ),
				( NULL , 'smiley_lol.gif', ':lol:', '15', '15' ),
				( NULL , 'smiley_sad.gif', ':sad:', '15', '15' ),
				( NULL , 'smiley_smile.gif', ':smile:', '15', '15' ),
				( NULL , 'smiley_surprised.gif', ':surprised:', '15', '15' ),
				( NULL , 'smiley_tongue.gif', ':tongue:', '15', '15' ),
				( NULL , 'smiley_wink.gif', ':wink:', '15', '15' );";
$sqldescription[11] = "- Adding smilies...";

$sql[12] = "ALTER TABLE `".$db['prefix']."user` ADD `r_edit_smilies` TINYINT( 1 ) NOT NULL AFTER `r_spam`";
$sqldescription[12] = "- Updating table for users...";

// update version number every time
if($settings['version'] == "0.6.4")
	{
	$sql[13] = "UPDATE `".$db['prefix']."settings` SET `version` = '0.6.6'";
	$sqldescription[13] = "- Updating version number...";
	}
else
	{
	$sql[13] = "UPDATE `".$db['prefix']."settings` SET `version` = '".MGB_VERSION."'";
	$sqldescription[13] = "- Updating version number...";
	}

$to = 13;

$config_file = "<?"."php\n\n";
$config_file .= "\t"."// THIS FILE WAS AUTOMATICALLY GENERATED BY MGB\n";
$config_file .= "\t"."// DO NOT MODIFY IT!\n\n";
$config_file .= "\t"."// Database settings\n";
$config_file .= "\t"."\$db = array();\n\n";
$config_file .= "\t"."\$db['hostname'] = '".$db['hostname']."';\n";
$config_file .= "\t"."\$db['dbname'] = '".$db['dbname']."';\n";
$config_file .= "\t"."\$db['username'] = '".$db['username']."';\n";
$config_file .= "\t"."\$db['password'] = '".$db['password']."';\n";
$config_file .= "\t"."\$db['prefix'] = '".$db['prefix']."';\n\n";
$config_file .= "\t"."\$mgb_installation_complete = TRUE;\n";
$config_file .= "?>";

if(write_config("../includes/config.inc.php", $config_file) === TRUE)
	{
	echo "\t\t<span style=\"font-family: verdana, arial, helvetica, sans-serif; font-size: 12px; font-weight: bold;\">- rewriting config.inc.php...</span>\n
	\t\t<span style=\"font-family: verdana, arial, helvetica, sans-serif; font-size: 12px; font-weight: bold; color: green;\">&nbsp;OK!<br /></span>\n";
	$success++;
	$count++;
	}
else
	{
	echo "\t\t<span style=\"font-family: verdana, arial, helvetica, sans-serif; font-size: 12px; font-weight: bold;\">- rewriting config.inc.php...</span>\n
	\t\t<span style=\"font-family: verdana, arial, helvetica, sans-serif; font-size: 12px; font-weight: bold; color: red;\">ERROR!<br /></span>\n";
	$count++;
	}
?>
